==> haskell-vty-5.20-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-vty.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vty
version: 5.20
id: vty-5.20-BOZJREm4yhuEY8BVr50Y9s
key: vty-5.20-BOZJREm4yhuEY8BVr50Y9s
license: BSD3
maintainer: Jonathan Daugherty (cygnus@foobox.com)
homepage: https://github.com/jtdaugherty/vty
synopsis: A simple terminal UI library
description:
    vty is terminal GUI library in the niche of ncurses. It is intended to
    be easy to use, have no confusing corner cases, and good support for
    common terminal types.
    .
    See the @vty-examples@ package as well as the program
    @test/interactive_terminal_test.hs@ included in the @vty@ package for
    examples on how to use the library.
    .
    Import the "Graphics.Vty" convenience module to get access to the core
    parts of the library.
    .
    &#169; 2006-2007 Stefan O'\''Rear; BSD3 license.
    .
    &#169; Corey O'\''Connor; BSD3 license.
    .
    &#169; Jonathan Daugherty; BSD3 license.
category: User Interfaces
author: AUTHORS
exposed: True
indefinite: False
exposed-modules:
    Codec.Binary.UTF8.Debug Data.Terminfo.Eval Data.Terminfo.Parse
    Graphics.Text.Width Graphics.Vty Graphics.Vty.Attributes
    Graphics.Vty.Config Graphics.Vty.Debug
    Graphics.Vty.DisplayAttributes Graphics.Vty.Error
    Graphics.Vty.Image Graphics.Vty.Image.Internal Graphics.Vty.Inline
    Graphics.Vty.Inline.Unsafe Graphics.Vty.Input
    Graphics.Vty.Input.Classify Graphics.Vty.Input.Classify.Parse
    Graphics.Vty.Input.Classify.Types Graphics.Vty.Input.Events
    Graphics.Vty.Input.Focus Graphics.Vty.Input.Loop
    Graphics.Vty.Input.Mouse Graphics.Vty.Input.Paste
    Graphics.Vty.Input.Terminfo Graphics.Vty.Output
    Graphics.Vty.Output.Interface Graphics.Vty.Output.Mock
    Graphics.Vty.Output.TerminfoBased Graphics.Vty.Output.XTermColor
    Graphics.Vty.Picture Graphics.Vty.PictureToSpans Graphics.Vty.Span
hidden-modules: Graphics.Vty.Attributes.Color
                Graphics.Vty.Attributes.Color240 Graphics.Vty.Debug.Image
                Graphics.Vty.Input.Terminfo.ANSIVT
abi: 4a34214ce896c7e8e31a5dd718bd228a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/vty-5.20
library-dirs: /usr/lib/ghc-8.2.2/site-local/vty-5.20
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/vty-5.20
hs-libraries: HSvty-5.20-BOZJREm4yhuEY8BVr50Y9s
depends:
    base-4.10.1.0 blaze-builder-0.4.0.2-IyhIxFYs3xU9dPk3t3umsA
    bytestring-0.10.8.2 containers-0.5.10.2 deepseq-1.4.3.0
    directory-1.3.0.2 filepath-1.4.1.2
    microlens-0.4.8.3-Hhd1pyfmRF65YkTRK2Yote
    microlens-mtl-0.1.11.1-7dSqMPU7BflI9dOF5LN9ml
    microlens-th-0.4.1.3-A4hK4aFT3a8H1Y8avKcT6Q
    hashable-1.2.6.1-A4keFPUppGkCw7JMX4jBTk
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    parallel-3.2.1.1-6PIhrl6oqe7Af1Z2sa6T1
    parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp
    stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x terminfo-0.4.1.0
    transformers-0.5.2.0 text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    unix-2.7.2.2 utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             blaze-builder-0.4.0.2-IyhIxFYs3xU9dPk3t3umsA=46678a76449231ad37b0ff9566dd89ca
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             microlens-0.4.8.3-Hhd1pyfmRF65YkTRK2Yote=d342bc9a9b35c935919ac21479dbef0f
             microlens-mtl-0.1.11.1-7dSqMPU7BflI9dOF5LN9ml=3622355c9ffb7a425ad3cab2b75d0a6c
             microlens-th-0.4.1.3-A4hK4aFT3a8H1Y8avKcT6Q=0a9da82dd00392e1b1481699ba3b8067
             hashable-1.2.6.1-A4keFPUppGkCw7JMX4jBTk=526c49aca960d0292e5723576545a03d
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             parallel-3.2.1.1-6PIhrl6oqe7Af1Z2sa6T1=f329a0732f0d1ccfb717a7145bfd3a72
             parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp=b942a04aec0a266706b2e8e67bd137e3
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad6bbd8e6ded9502ff897b95774cdf26
             terminfo-0.4.1.0=acb5ccd00d0581773cc2733d8844bf64
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
haddock-interfaces: /usr/share/doc/haskell-vty/html/vty.haddock
haddock-html: /usr/share/doc/haskell-vty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vty-5.20-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-vty.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vty
version: 5.20
id: vty-5.20-EXWyEEf0aZ9FQBE3Tu02rQ
key: vty-5.20-EXWyEEf0aZ9FQBE3Tu02rQ
license: BSD3
maintainer: Jonathan Daugherty (cygnus@foobox.com)
homepage: https://github.com/jtdaugherty/vty
synopsis: A simple terminal UI library
description:
    vty is terminal GUI library in the niche of ncurses. It is intended to
    be easy to use, have no confusing corner cases, and good support for
    common terminal types.
    .
    See the @vty-examples@ package as well as the program
    @test/interactive_terminal_test.hs@ included in the @vty@ package for
    examples on how to use the library.
    .
    Import the "Graphics.Vty" convenience module to get access to the core
    parts of the library.
    .
    &#169; 2006-2007 Stefan O'\''Rear; BSD3 license.
    .
    &#169; Corey O'\''Connor; BSD3 license.
    .
    &#169; Jonathan Daugherty; BSD3 license.
category: User Interfaces
author: AUTHORS
exposed: True
indefinite: False
exposed-modules:
    Codec.Binary.UTF8.Debug Data.Terminfo.Eval Data.Terminfo.Parse
    Graphics.Text.Width Graphics.Vty Graphics.Vty.Attributes
    Graphics.Vty.Config Graphics.Vty.Debug
    Graphics.Vty.DisplayAttributes Graphics.Vty.Error
    Graphics.Vty.Image Graphics.Vty.Image.Internal Graphics.Vty.Inline
    Graphics.Vty.Inline.Unsafe Graphics.Vty.Input
    Graphics.Vty.Input.Classify Graphics.Vty.Input.Classify.Parse
    Graphics.Vty.Input.Classify.Types Graphics.Vty.Input.Events
    Graphics.Vty.Input.Focus Graphics.Vty.Input.Loop
    Graphics.Vty.Input.Mouse Graphics.Vty.Input.Paste
    Graphics.Vty.Input.Terminfo Graphics.Vty.Output
    Graphics.Vty.Output.Interface Graphics.Vty.Output.Mock
    Graphics.Vty.Output.TerminfoBased Graphics.Vty.Output.XTermColor
    Graphics.Vty.Picture Graphics.Vty.PictureToSpans Graphics.Vty.Span
hidden-modules: Graphics.Vty.Attributes.Color
                Graphics.Vty.Attributes.Color240 Graphics.Vty.Debug.Image
                Graphics.Vty.Input.Terminfo.ANSIVT
abi: 57c2dd86f019a4b088d8e935ecf33537
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/vty-5.20
library-dirs: /usr/lib/ghc-8.2.2/site-local/vty-5.20
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/vty-5.20
hs-libraries: HSvty-5.20-EXWyEEf0aZ9FQBE3Tu02rQ
depends:
    base-4.10.1.0 blaze-builder-0.4.0.2-IyhIxFYs3xU9dPk3t3umsA
    bytestring-0.10.8.2 containers-0.5.10.2 deepseq-1.4.3.0
    directory-1.3.0.2 filepath-1.4.1.2
    microlens-0.4.8.3-Hhd1pyfmRF65YkTRK2Yote
    microlens-mtl-0.1.11.1-7dSqMPU7BflI9dOF5LN9ml
    microlens-th-0.4.1.3-A4hK4aFT3a8H1Y8avKcT6Q
    hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    parallel-3.2.1.1-6PIhrl6oqe7Af1Z2sa6T1
    parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp
    stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x terminfo-0.4.1.0
    transformers-0.5.2.0 text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    unix-2.7.2.2 utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             blaze-builder-0.4.0.2-IyhIxFYs3xU9dPk3t3umsA=46678a76449231ad37b0ff9566dd89ca
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             microlens-0.4.8.3-Hhd1pyfmRF65YkTRK2Yote=d342bc9a9b35c935919ac21479dbef0f
             microlens-mtl-0.1.11.1-7dSqMPU7BflI9dOF5LN9ml=3622355c9ffb7a425ad3cab2b75d0a6c
             microlens-th-0.4.1.3-A4hK4aFT3a8H1Y8avKcT6Q=0a9da82dd00392e1b1481699ba3b8067
             hashable-1.2.7.0-D1kf6WO5TlN7xk82E4ZIan=7c14723fffdda860d330f4ccf53597f4
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             parallel-3.2.1.1-6PIhrl6oqe7Af1Z2sa6T1=f329a0732f0d1ccfb717a7145bfd3a72
             parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp=b942a04aec0a266706b2e8e67bd137e3
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad6bbd8e6ded9502ff897b95774cdf26
             terminfo-0.4.1.0=acb5ccd00d0581773cc2733d8844bf64
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
haddock-interfaces: /usr/share/doc/haskell-vty/html/vty.haddock
haddock-html: /usr/share/doc/haskell-vty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
